from os import path

from nib import Processor, render

@render
class BreadcrumbProcessor(Processor):
    def process(self, documents, resources):
        uris = {d.uri.strip('/'): d for d in documents}

        for doc in documents:
            if 'nocrumbs' in doc:
                continue

            breadcrumbs = []
            segments = doc.uri.strip('/').split('/')
            uri = ''

            for segment in segments:
                uri = path.join(uri, segment).strip('/')
                if uri in uris:
                    page = uris[uri]
                    if 'title' in page and page['title']:
                        breadcrumbs.append(uris[uri])

            doc['breadcrumbs'] = breadcrumbs

        return documents, resources




preprocessors = []
postprocessors = []
document_processors = {}
resource_processors = {}
markup_processors = {}
render_processors = []

def resource(extensions):
    if type(extensions) != list:
        extensions = [extensions]

    def decorator(cls):
        for extension in extensions:
            resource_processors[extension] = cls
        return cls
    return decorator

def before(cls):
    preprocessors.append(cls)
    return cls

def document(document_type):
    def decorator(cls):
        if document_type not in document_processors:
            document_processors[document_type] = []
        document_processors[document_type].append(cls)
        return cls
    return decorator

def after(cls):
    postprocessors.append(cls)
    return cls

def markup(extensions):
    if type(extensions) != list:
        extensions = [extensions]

    def decorator(cls):
        for extension in extensions:
            if extension not in markup_processors:
                markup_processors[extension] = []
            markup_processors[extension].append(cls)
    return decorator

def render(cls):
    render_processors.append(cls)
    return cls

class Processor(object):
    def __init__(self, options):
        self.options = options

    def process(self, documents, resources):
        new_documents = []
        for document in documents:
            result = self.document(document)
            if result:
                new_documents.append(document)

        new_resources = []
        for resource in resources:
            result = self.resource(resource)
            if result:
                new_resources.append(resource)

        return new_documents, new_resources

    def document(self, document):
        return document

    def resource(self, resource):
        return resource



import datetime
import time

from nib import jinja

@jinja('time')
def timeformat(t=None, f='%Y-%m-%d %I:%M %p'):
    if t is None:
        t = time.gmtime()
    elif isinstance(t, datetime.date) or isinstance(t, datetime.datetime):
        t = t.timetuple()
    elif isinstance(t, float):
        t = time.gmtime(t)

    s = time.strftime(f, t)
    return s

@jinja('atomtime')
def atomtimeformat(t=None, f='%Y-%m-%dT%I:%M:%SZ'):
    return timeformat(t,f)

@jinja('rsstime')
def rsstimeformat(t=None, f='%a, %d %b %Y %I:%M:%S GMT'):
    return timeformat(t,f)

@jinja('date')
def dateformat(t=None, f='%Y-%m-%d'):
    return timeformat(t,f)

@jinja('longdate')
def longdateformat(t=None, f='%B %d, %Y'):
    return timeformat(t, f)




import importlib
import os
from os import path

cwd = path.abspath(path.dirname(__file__))
files = os.listdir(cwd)

def load(options):
    load_plugins = options['load_plugins']
    ignore_plugins = options['ignore_plugins']

    for filename in files:
        name, ext = path.splitext(filename)

        if name.startswith('_'):
            continue

        if ext == '.py':
            if name in ignore_plugins:
                continue

            if name in load_plugins or '*' in load_plugins:
                importlib.import_module('nib.plugins.' + name)
